--- Lib/distutils/dist.py.old	2012-04-10 01:25:34.000000000 +0200
+++ Lib/distutils/dist.py	2016-08-01 05:35:16.000000000 +0200
@@ -53,6 +53,7 @@
                       ('quiet', 'q', "run quietly (turns verbosity off)"),
                       ('dry-run', 'n', "don't actually do anything"),
                       ('help', 'h', "show detailed help message"),
+                      ('no-user-cfg', None,'ignore pydistutils.cfg in your home directory'),
                      ]
 
     # 'common_usage' is a short (2-3 line) string describing the common
@@ -260,6 +261,12 @@
                     else:
                         sys.stderr.write(msg + "\n")
 
+        # no-user-cfg is handled before other command line args
+        # because other args override the config files, and this
+        # one is needed before we can load the config files.
+        # If attrs['script_args'] wasn't passed, assume false.
+        self.want_user_cfg = '--no-user-cfg' not in (self.script_args or [])
+
         self.finalize_options()
 
     def get_option_dict(self, command):
@@ -312,6 +319,9 @@
         Distutils __inst__.py file lives), a file in the user's home
         directory named .pydistutils.cfg on Unix and pydistutils.cfg
         on Windows/Mac, and setup.cfg in the current directory.
+
+        The file in the user's home directory can be disabled with the
+        --no-user-cfg option.
         """
         files = []
         check_environ()
@@ -332,7 +342,7 @@
 
         # And look for the user config file
         user_file = os.path.join(os.path.expanduser('~'), user_filename)
-        if os.path.isfile(user_file):
+        if self.want_user_cfg and os.path.isfile(user_file):
             files.append(user_file)
 
         # All platforms support local setup.cfg
@@ -340,6 +350,8 @@
         if os.path.isfile(local_file):
             files.append(local_file)
 
+        if DEBUG:
+            print("using config files: %s" % ', '.join(files))
         return files
 
     def parse_config_files(self, filenames=None):
